@@ -5,10 +5,10 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-annotation.el,v 1.167 2010/09/26 04:23:13 skk-cvs Exp $
+;; Version: $Id: skk-annotation.el,v 1.171 2010/12/12 11:09:19 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
 ;; Created: Oct. 27, 2000.
-;; Last Modified: $Date: 2010/09/26 04:23:13 $
+;; Last Modified: $Date: 2010/12/12 11:09:19 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -41,30 +41,30 @@
 ;;
 ;;   (setq skk-show-annotation t)
 ;;
-;; $B$H(B ~/.emacs $B$K=q$-$^$7$g$&!#<-=q$N8uJd$K(B `;' $B$+$i;O$^$kJ8;zNs$,$"$l(B
-;; $B$P!"$=$N3:Ev$N8uJd$,JQ49$5$l$F%P%C%U%!$K=PNO$5$l$?:]!"(B`;' $B0J9_$r$=(B
-;; $B$N8uJd$N%"%N%F!<%7%g%s$H$7$F%(%3!<%(%j%"$KI=<($7$^$9!#(B
+;; $B$H(B ~/.skk $B$K=q$-$^$7$g$&!#<-=q$N8uJd$K(B `;' $B$+$i;O$^$kJ8;zNs$,$"$l$P!"(B
+;; $B$=$N3:Ev$N8uJd$,JQ49$5$l$F%P%C%U%!$K=PNO$5$l$?:]$K(B `;' $B0J9_$r$=$N8u(B
+;; $BJd$N%"%N%F!<%7%g%s$H$7$F%(%3!<%(%j%"$KI=<($7$^$9!#(B
 ;;
 ;;   (setq skk-annotation-show-as-message nil)
 ;;
-;; $B$H(B ~/.emacs $B$K=q$$$?>l9g$O!"(Bother-window $B$r0l;~E*$K3+$$$F%"%N%F!<%7%g(B
+;; $B$H(B ~/.skk $B$K=q$$$?>l9g$O!"(Bother-window $B$r0l;~E*$K3+$$$F%"%N%F!<%7%g(B
 ;; $B%s$rI=<($7$^$9!#(Bother-window $B$O$=$N8uJd$K$D$$$F3NDj$9$k$+!"$=$N8uJd(B
 ;; $B$NA*Br$r;_$a$k(B ($B<!$N8uJd$rA*Br$7$?$j!"(Bquit $B$7$?$j(B) $B$9$k$H<+F0E*$KJD(B
 ;; $B$8$i$l$^$9!#(B
 ;;
-;; SKK $B$G$O(B 5 $BHVL\$N8uJd0J9_$r%(%3!<%(%j%"$r;H$C$FI=<($7$^$9!#=>$$!"(B5
-;; $BHVL\0J9_$N8uJd$K$D$$$F$O!"(Bskk-annotation-show-as-message $B$,(B t $B$G$b(B
+;; SKK $B$G$O(B 5 $BHVL\$N8uJd0J9_$r%(%3!<%(%j%"$r;H$C$FI=<($7$^$9!#=>$C$F(B
+;; $B#5HVL\0J9_$N8uJd$K$D$$$F$O!"(Bskk-annotation-show-as-message $B$,(B t $B$G$b(B
 ;; $B%&%#%s%I%&$r3+$$$F%"%N%F!<%7%g%s$rI=<($7$^$9!#(B
 ;;
-;; $B$"$kC18l$K$D$$$F!"%"%N%F!<%7%g%s$rIU$1$?$$$H$-$O!"3NDj$7$?D>8e$KF1(B
-;; $B$8%P%C%U%!$G(B
+;; $B$"$kC18l$K%"%N%F!<%7%g%s$rIU$1$?$$$H$-$O!"3NDj$7$?D>8e$KF1$8%P%C%U%!(B
+;; $B$G(B
 ;;
 ;;   M-x skk-annotation-add
 ;;
-;; $B$7$^$7$g$&!#%"%N%F!<%7%g%s$rJT=8$9$k%P%C%U%!$,3+$$$F!"%+%l%s%H%P%C(B
-;; $B%U%!$K$J$j$^$9$N$G!"$=$3$X%"%N%F!<%7%g%s$rIU$1$^$7$g$&!#(B
-;; 1 $B9T$G$"$kI,MW$O$"$j$^$;$s$,!"J#?t9T$N%"%N%F!<%7%g%s$rIU$1$k$H(B echo
-;; area $B$XI=<($5$l$?$H$-$KA4BN$,8+$($J$/$J$j$^$9!#(B
+;; $B$H<B9T$7$^$7$g$&!#%"%N%F!<%7%g%s$rJT=8$9$k%P%C%U%!$,3+$$$F!"%+%l%s%H(B
+;; $B%P%C%U%!$K$J$j$^$9$N$G!"$=$3$X%"%N%F!<%7%g%s$rIU$1$^$7$g$&!#(B
+;; 1 $B9T$G$"$kI,MW$O$"$j$^$;$s$,!"J#?t9T$N%"%N%F!<%7%g%s$rIU$1$k$H%(%3!<(B
+;; $B%(%j%"$KI=<($7$?$H$-$KA4BN$,8+$($J$/$J$j$^$9!#(B
 ;; $B$^$?!"(B`;' $B$NJ8;z<+BN$OF~$l$kI,MW$O$"$j$^$;$s!#(B
 ;; $B:#$^$G$K4{$KIU$1$F$$$?%"%N%F!<%7%g%s$,$"$l$PJT=8%P%C%U%!$,I=<($5$l(B
 ;; $B$?$H$-$K$=$N%"%N%F!<%7%g%s$,(B prefix $BE*$K=PNO$5$l$^$9!#4{B8$N%"%N%F!<(B
@@ -924,7 +924,7 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 (defun skk-annotation-wikipedia-1 (word source last)
   "Wiktionary/Wikipedia $B$N(B WORD $B$KAjEv$9$k5-;v$r<B:]$K%@%&%s%m!<%I$7$FD4$Y$k!#(B
 $B3:Ev%Z!<%8(B (html) $B$r%@%&%s%m!<%I$9$k5!G=$O(B Emacs $B$KIUB0$N(B URL $B%Q%C%1!<%8$K0M(B
-$B$k!#E,@Z$J(B URL $B$r@8@.$9$k$?$a$K$O!"(B"
+$B$k!#(B"
   (require 'html2text)
   (require 'url)
   ;;
@@ -1352,9 +1352,7 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
 (defun skk-annotation-wikipedia-retrieved (&rest args)
   (cond ((or (member "deleted\n" (assq 'error (memq :error (car args))))
 	     (< (buffer-size) 7)
-	     (not (progn
-		    (goto-char (point-max))
-		    (search-backward "</html>" nil t))))
+	     (not (skk-annotation-wikipedia-test-html-tag)))
 	 ;; $BIT40A4$J(B retrieval $B$K$*$$$F$b(B STATUS $B$,(B nil $B$H$J$k$3$H$,$"$k$N$G(B
 	 ;; $B$3$3$GD4@0$9$k!#(B
 	 (kill-buffer (current-buffer))
@@ -1363,6 +1361,24 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
 	(t
 	 (throw 'skk-annotation-wikipedia-retrieved (current-buffer)))))
 
+(defun skk-annotation-wikipedia-test-html-tag ()
+  ;; html $B%G!<%?$,:G8e$N(B </html> $B%?%0$r;}$D$3$H$r3NG'$9$k(B
+  (goto-char (point-min))
+  (when (re-search-forward "^Content-Encoding: gzip$" nil t)
+    ;; html $B$,(B gzip $B05=L$GAw$i$l$FMh$?>l9g(B
+    (let ((gzip (executable-find "gzip")))
+      (unless gzip
+	(error "%s" "$B$3$NFbMF$rI=<($9$k$K$O(B gzip $B$,I,MW$G$9(B"))
+      (while (and (not (looking-at "^\n"))
+		  (not (eobp)))
+	(forward-line 1))
+      (forward-line 1)
+      (when (< (point) (point-max))
+	(let ((coding-system-for-write 'binary))
+	  (call-process-region (point) (point-max) gzip t t t "-cd")))))
+  (goto-char (point-max))
+  (search-backward "</html>" nil t))
+
 ;;;###autoload
 (defun skk-annotation-treat-wikipedia (word &optional sources)
   "WORD $B$,A^F~$5$l$k$H$-$KI=<($5$l$k$Y$-Cm<a$r@8@.$9$k!#(B
