@@ -52,9 +52,9 @@
     (skk-japanese-message-and-error
      (const :tag "$B%a%C%;!<%8$OF|K\8l$GDLCN$9$k(B" t) "")
     (skk-verbose
-     (const :tag "$B$U$D$&$h$jB?$/$N%a%C%;!<%8$rI=<($9$k(B" t) "")
+     (const :tag "$B=u8@E*%a%C%;!<%8$rI=<($9$k(B" t) "")
     (skk-show-japanese-menu
-     (const :tag "$BF|K\8l%a%K%e!<$r;HMQ$9$k(B" t) "")
+     (const :tag "$B%a%K%e!<%P!<$rF|K\8l$GI=<($9$k(B" t) "")
     (skk-show-annotation
      (radio :tag "$BJQ49;~$KCp<a$rI=<($9$k!)(B"
 	    (const :tag "$B>o$KI=<((B" t)
