@@ -29,6 +29,7 @@
 
 (eval-when-compile
   (require 'cl)
+  (require 'ja-dic-utl)
   (require 'tooltip)
   (require 'skk-vars)
   (require 'skk-macs)
@@ -111,6 +112,7 @@
     ("Count Jisyo Candidates" . "$B<-=qCf$N8uJd?t$r?t$($k(B")
     ("Save Jisyo" . "$B<-=q$rJ]B8$9$k(B")
     ("Undo Kakutei" . "$B3NDj$r<h$j>C$9(B ($B%"%s%I%%!<(B)")
+    ("Restart SKK" . "SKK $B$N:F5/F0(B")
     ("Version" . "SKK $B$N%P!<%8%g%s(B")
     ("Daredevil SKK Menu" . "Daredevil SKK $B%a%K%e!<(B")
     ("Hankaku alphabet" . "$BH>3Q1Q?t(B")
@@ -682,6 +684,76 @@
 
 ;;@@ Other functions.
 
+;;;###autoload
+(defun skk-search-ja-dic ()
+  "GNU Emacs $B$KIUB0$9$k$+$J4A;zJQ49<-=q$rMQ$$$F8!:w$9$k!#(B
+$B8=:_$N(B Emacs $B$K$O(B SKK-JISYO.L $B$r4p$KJQ49$5$l$?(B ja-dic.el $B$,IUB0$7$F$$$k!#(B
+$B$3$N<-=q%G!<%?$rMQ$$$FAw$j$"$j!"Aw$j$J$7!"@\F,<-!"@\Hx<-$NJQ49$r9T$&!#(B
+$B$?$@$7!"(BSKK-JISYO.L $B$N$h$&$J1Q?tJQ49!"?tCMJQ49$J$I$O$G$-$J$$!#(B"
+  (require 'ja-dic-utl)
+  ;; Mostly from ja-dic-utl.el.
+  (when (and (locate-library "ja-dic/ja-dic")
+	     (not skkdic-okuri-nasi))
+    (ignore-errors
+	(load-library "ja-dic/ja-dic")))
+  (when skkdic-okuri-nasi
+    (let* ((len (length skk-henkan-key))
+	   (vec (make-vector len 0))
+	   (i 0)
+	   entry result)
+      ;; At first, generate vector VEC from SEQ for looking up SKK
+      ;; alists.  Nth element in VEC corresponds to Nth element in SEQ.
+      ;; The values are decided as follows.
+      ;;   If SEQ[N] is `$B!<(B', VEC[N] is 0,
+      ;;   else if SEQ[N] is a Hiragana character, VEC[N] is:
+      ;;     ((The 2nd position code of SEQ[N]) - 32),
+      ;;   else VEC[N] is 128.
+      (while (< i len)
+	(let ((ch (aref skk-henkan-key i))
+	      code)
+	  (cond ((= ch ?$B!<(B)
+		 (aset vec i 0))
+		((and (eval-when-compile (>= emacs-major-version 23))
+		      (>= ch (car skkdic-jisx0208-hiragana-block))
+		      (<= ch (cdr skkdic-jisx0208-hiragana-block))
+		      (setq code (encode-char ch 'japanese-jisx0208)))
+		 (aset vec i (- (logand code #xFF) 32)))
+		((and (eval-when-compile (<= emacs-major-version 22))
+		      (setq code (split-char ch))
+		      (eq (car code) 'japanese-jisx0208)
+		      (= (nth 1 code) skkdic-jisx0208-hiragana-block))
+		 (aset vec i (- (nth 2 code) 32)))
+		(t
+		 (aset vec i 128))))
+	(setq i (1+ i)))
+      (cond
+       (skk-henkan-okurigana ; $BAw$j$"$jJQ49(B
+	(let ((okurigana (assq (aref skk-henkan-okurigana 0)
+			       skkdic-okurigana-table))
+	      orig-element)
+	  (when okurigana
+	    (setq orig-element (aref vec (1- len)))
+	    (aset vec (1- len) (- (cdr okurigana)))
+	    (when (and (setq entry (lookup-nested-alist vec
+							skkdic-okuri-ari
+							len 0 t))
+		       (consp (car entry)))
+	      (setq entry (nreverse (copy-sequence (car entry))))))))
+       ((string-match ">$" skk-henkan-key) ; $B@\F,<-(B
+	(setq entry (lookup-nested-alist vec skkdic-prefix (1- len) 0 t)))
+       ((string-match "^>" skk-henkan-key) ; $B@\Hx<-(B
+	(setq entry (lookup-nested-alist vec skkdic-postfix len 1 t)))
+       (t ; $BDL>o$NAw$j$J$7JQ49(B
+	(setq entry (lookup-nested-alist vec skkdic-okuri-nasi len 0 t))))
+      ;;
+      (when (consp (car entry))
+	(setq entry (car entry)))
+      (while entry
+	(when (stringp (car entry))
+	  (setq result (nconc result (list (car entry)))))
+	(setq entry (cdr entry)))
+      result)))
+
 ;; skk-kcode.el $B$h$j!#(B
 ;; XEmacs $B$G$N%(%i!<2sHr$N$?$a$K$3$N4X?t$r0l;~B`Hr$7$F$$$k!#(B
 ;; 2$BLL(B
