@@ -5,9 +5,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-gadget.el,v 1.40 2010/09/10 15:47:02 skk-cvs Exp $
+;; Version: $Id: skk-gadget.el,v 1.44 2010/11/29 11:25:43 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/09/10 15:47:02 $
+;; Last Modified: $Date: 2010/11/29 11:25:43 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -156,18 +156,32 @@ AND-TIME $B$O;~9o$bI=<($9$k$+$I$&$+(B \(boolean\)$B!#(B"
 		year month day day-of-week hour minute second)
       (format (or format "%s$BG/(B%s$B7n(B%s$BF|(B(%s)") year month day day-of-week))))
 
+(defun skk-today-execute-char ()
+  (let ((tree (nth 4 skk-rule-tree))
+	list char)
+    (while (setq list (car tree))
+      (if (memq 'skk-today list)
+	  (setq char (char-to-string (car list))))
+      (setq tree (cdr tree)))
+    char))
+
 ;;;###autoload
 (defun skk-today (arg)
   "\
-`current-time-string' $B$N=PNO$r2C9)$7!"8=:_$NF|;~$rI=$9J8;zNs$r:n$j!"A^F~$9$k!#(B
-$B<B<AE*$K(B today $B%(%s%H%j$N8F=P$7$J$N$G!"8D?M<-=q$N(B today $B%(%s%H%j$K$h$j%+%9%?%^(B
-$B%$%:$9$k$3$H$,$G$-$k!#(B"
+`current-time-string' $B$N=PNO$r2C9)$7!"8=:_$NF|;~$rI=$9J8;zNs$r:n$j!"A^F~(B
+$B$9$k!#<B<AE*$K!V(Btoday $B%(%s%H%j$N8F$S=P$7!W$@$1$J$N$G!"%+%9%?%^%$%:$O8D?M(B
+$B<-=q$N(B today $B%(%s%H%j$K$h$k!#(B"
   (interactive "p")
-  (unless skk-mode
-    (skk-mode 1))
-  (skk-set-henkan-point-subr)
-  (insert "today")
-  (skk-start-henkan arg))
+  (if (and (eq skk-henkan-mode 'on)	;$B"&%b!<%I(B
+	   (equal (this-command-keys) (skk-today-execute-char))
+	   (< skk-henkan-start-point (point)))
+      (this-command-keys)
+    ;;
+    (unless skk-mode
+      (skk-mode 1))
+    (skk-set-henkan-point-subr)
+    (insert "today")
+    (skk-start-henkan arg)))
 
 ;;;###autoload
 (defun skk-clock (&optional kakutei-when-quit time-signal)
