@@ -1,4 +1,4 @@
-;;; skk-jisyo-edit-mode.el --- major mode for editing SKK dictionaries -*- coding: euc-jp -*-
+;;; skk-jisyo-edit-mode.el --- major mode for editing SKK dictionaries -*- coding: iso-2022-jp -*-
 
 ;; Copyright (C) 2001-2010 SKK Development Team
 
@@ -29,8 +29,6 @@
 ;;; Code:
 
 (eval-when-compile
-  (require 'poe)
-  (require 'static)
   (defvar font-lock-defaults))
 
 (defvar skk-jisyo-edit-map nil
@@ -74,8 +72,8 @@
   (setq skk-jisyo-edit-syntax-table (make-syntax-table))
   (set-syntax-table skk-jisyo-edit-syntax-table)
   (let ((map (make-sparse-keymap)))
-    (static-cond
-     ((featurep 'xemacs)
+    (cond
+     ((eval-when-compile (featurep 'xemacs))
       (set-keymap-parents map (list skk-jisyo-edit-map))
       (use-local-map map))
      (t
@@ -85,8 +83,7 @@
   (run-hooks 'skk-jisyo-edit-mode-hook))
 
 ;;;###autoload
-(when (eval-when-compile (>= emacs-major-version 21))
-  (add-to-list 'auto-mode-alist '("SKK-JISYO" . skk-jisyo-edit-mode) t))
+(add-to-list 'auto-mode-alist '("SKK-JISYO" . skk-jisyo-edit-mode) t)
 ;;;###autoload
 (add-to-list 'auto-mode-alist '("\\.skk-jisyo\\(\\.BAK\\|\\.bak\\|~\\)?$"
 				. skk-jisyo-edit-mode))
@@ -99,27 +96,26 @@
   (interactive "P")
   (when coding-system
     (setq coding-system (read-coding-system
-			 "ĿͼΥɷϤ: "
+			 "$B8D?M<-=q$N%3!<%I7O$r;XDj(B: "
 			 (skk-find-coding-system skk-jisyo-code))))
   (unless coding-system
     (setq coding-system (skk-find-coding-system skk-jisyo-code)))
   ;;
-  (when (skk-y-or-n-p "򥻡֤ޤ "
+  (when (skk-y-or-n-p "$B<-=q$r%;!<%V$7$^$9$+!)(B "
 		      "Save jisyo? ")
     (skk-save-jisyo))
   (message nil)
   (setq skk-jisyo-edit-original-window-configuration
 	(current-window-configuration))
-  ;; SKK ΥɤϸȽ꤬ꤦ뤿ᡢդ
+  ;; SKK $B<-=q$N%3!<%I$O8mH=Dj$,$"$j$&$k$?$a!"Cm0U$9$k(B
   (let ((coding-system-for-read coding-system))
     (find-file skk-jisyo))
   (unless (eq major-mode 'skk-jisyo-edit-mode)
     (skk-jisyo-edit-mode))
-  (static-when (or (featurep 'xemacs)
-		   (< emacs-major-version 21))
+  (when (eval-when-compile (featurep 'xemacs))
     (make-local-hook 'kill-buffer-hook))
-  ;; Խ˺ټ¹ԤƤ⡢
-  ;;  Τ褦ˤʤ뤫 skk-update-jisyo-function 롣
+  ;; $BJT=8Cf$K:FEY<B9T$7$F$b!"(B
+  ;; $B"-(B $B$N$h$&$K$J$k$+$i(B skk-update-jisyo-function $B$OI|85$5$l$k!#(B
   ;; '((lambda nil
   ;;     (setq skk-update-jisyo-function #'ignore))
   ;;   (lambda nil
@@ -142,7 +138,7 @@
   (local-set-key "\C-c\C-c"
 		 #'(lambda ()
 		     (interactive)
-		     (when (skk-y-or-n-p "Խλޤ "
+		     (when (skk-y-or-n-p "$BJT=8$r=*N;$7$^$9$+!)(B "
 					 "Finish editing jisyo? ")
 		       (save-buffer)
 		       (kill-buffer (current-buffer))
@@ -153,7 +149,7 @@
   (local-set-key "\C-c\C-k"
 		 #'(lambda ()
 		     (interactive)
-		     (when (skk-y-or-n-p "Խߤޤ "
+		     (when (skk-y-or-n-p "$BJT=8$rCf;_$7$^$9$+!)(B "
 					 "Abort editing jisyo? ")
 		       (set-buffer-modified-p nil)
 		       (kill-buffer (current-buffer))
@@ -163,7 +159,7 @@
 
 (defadvice skk-henkan-in-minibuff (before notify-no-effect disable)
   (ding)
-  (skk-message "ĿͼԽǤϿȿǤޤ"
+  (skk-message "$B8D?M<-=q$NJT=8Cf$G$9!#EPO?$OH?1G$5$l$^$;$s!#(B"
 	       "You are editing private jisyo.  This registration has no effect.")
   (sit-for 1.5))
 
@@ -171,7 +167,7 @@
   (if (eq skk-henkan-mode 'active)
       (progn
 	(ding)
-	(skk-message "ĿͼԽǤǤޤ"
+	(skk-message "$B8D?M<-=q$NJT=8Cf$G$9!#:o=|$G$-$^$;$s!#(B"
 		     "You are editing private jisyo.  Can't purge."))
     ad-do-it))
 
