@@ -5,9 +5,9 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-kakasi.el,v 1.32 2010/09/11 14:59:59 skk-cvs Exp $
+;; Version: $Id: skk-kakasi.el,v 1.34 2010/11/28 21:03:28 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/09/11 14:59:59 $
+;; Last Modified: $Date: 2010/11/28 21:03:28 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -66,6 +66,16 @@
     (goto-char start)
     (insert-and-inherit str)))
 
+;;;###autoload
+(defun skk-gyakubiki-and-henkan (start end)
+  "$BNN0h$N4A;z$r$R$i$,$J$KJQ49$7!"$=$N$R$i$,$J$r8+=P$78l$H$7$F$+$J4A;zJQ49$r<B9T$9$k!#(B"
+  (interactive "*r")
+  (let ((str (skk-gyakubiki-1 start end nil)))
+    (delete-region start end)
+    (skk-set-henkan-point-subr)
+    (insert-and-inherit str)
+    (skk-start-henkan nil)))
+
 ;;;###autoload
 (defun skk-gyakubiki-message (start end &optional all)
   "$BNN0h$N4A;z!"Aw$j2>L>$rA4$F$R$i$,$J$KJQ498e!"%(%3!<$9$k!#(B
